Struct Options

#[non_exhaustive]
pub struct Options { pub multithreaded_bit_reversal: bool, }
Calling FFT routines without specifying options will automatically select reasonable defaults depending on the input size and other factors.

You only need to tune these options if you are trying to squeeze maximum performance out of a known hardware platform that you can benchmark at varying input sizes.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
multithreaded_bit_reversal: bool

Whether to run the bit reversal step in 2 threads instead of one. This is beneficial only at large input sizes (i.e. gigabytes of data). The exact threshold where it starts being beneficial varies depending on the hardware.