pub struct Planner64 {
pub twiddles_re: Vec<f64>,
pub twiddles_im: Vec<f64>,
pub direction: Direction,
}Expand description
The planner is responsible for pre-computing and storing twiddle factors for all the
log_2(N) stages of the FFT.
The amount of twiddle factors should always be a power of 2. In addition,
the amount of twiddle factors should always be (1/2) * N
Fields
twiddles_re: Vec<f64>The real components of the twiddle factors
twiddles_im: Vec<f64>The imaginary components of the twiddle factors
direction: DirectionThe direction of the FFT associated with this Planner
Implementations
Sourceimpl Planner64
impl Planner64
Sourcepub fn new(num_points: usize, direction: Direction) -> Self
pub fn new(num_points: usize, direction: Direction) -> Self
Create a Planner for an FFT of size num_points.
The twiddle factors are pre-computed based on the provided Direction.
For Forward, use Direction::Forward.
For Reverse, use Direction::Reverse.
Panics
Panics if num_points < 1 or if num_points is not a power of 2.